Rucio Administrative CLI — Rucio 1.2 documentation

# Rucio Administrative CLI

    usage: rucio-admin [-h] [--version] [--verbose] [-H ADDRESS]
                       [--auth_host ADDRESS] [-a ACCOUNT] [-S AUTH_STRATEGY]
                       [-T TIMEOUT] [-u USERNAME] [-pwd PASSWORD]
                       [--certificate CERTIFICATE]
                       [--ca-certificate CA_CERTIFICATE]
                       {account,identity,rse,scope,config,subscription,replicas}
                       ...

## Named Arguments

`--version` | show program’s version number and exit
`--verbose, -v` | Print more verbose output Default: False
`-H, --host` | The Rucio API host
`--auth_host` | The Rucio Authentication host
`-a, --account` | Rucio account to use
`-S, --auth-strategy`
| Authentication strategy (userpass, x509, ssh …)
`-T, --timeout` | Set all timeout values to SECONDS
`-u, --user` | username
`-pwd, --password`
| password
`--certificate` | Client certificate file
`--ca-certificate`
| CA certificate to verify peer against (SSL)

## Sub-commands:

### account

Account methods

    rucio-admin account [-h]

                        {list,list-attributes,add-attribute,delete-attribute,add,delete,info,list-identities,set-limits,get-limits,delete-limits,ban,unban}
                        ...

#### Sub-commands:

##### list

List Rucio accounts

    rucio-admin account list [-h] [--type ACCOUNT_TYPE] [--id IDENTITY]
                             [--filters FILTERS]

###### Named Arguments

`--type` | Account Type (USER, GROUP, SERVICE)
`--id` | Identity (e.g. DN)
`--filters` | Filter arguments in form key=value,another_key=next_value

##### list-attributes

List attributes for an account

    rucio-admin account list-attributes [-h] account

###### Positional Arguments

`account` | Account name

##### add-attribute

Add attribute for an account

    rucio-admin account add-attribute [-h] --key KEY --value VALUE account

###### Positional Arguments

`account` | Account name

###### Named Arguments

`--key` | Attribute key
`--value` | Attribute value

##### delete-attribute

Delete attribute for an account

    rucio-admin account delete-attribute [-h] --key KEY account

###### Positional Arguments

`account` | Account name

###### Named Arguments

`--key` | Attribute key

##### add

Add Rucio account

    rucio-admin account add [-h] [--type ACCOUNTTYPE] [--email ACCOUNTEMAIL]
                            account

###### Positional Arguments

`account` | Account name

###### Named Arguments

`--type` | Account Type Default: “USER”
`--email` | Email address associated with the account

##### delete

Delete Rucio account

    rucio-admin account delete [-h] acnt

###### Positional Arguments

`acnt` | Account name

##### info

Show detailed information about an account

    rucio-admin account info [-h] account

###### Positional Arguments

`account` | Account name

##### list-identities

List all identities on an account

    rucio-admin account list-identities [-h] account

###### Positional Arguments

`account` | Account name

##### set-limits

Set the limits for the provided account

    rucio-admin account set-limits [-h] account rse bytes

###### Positional Arguments

`account` | Account name
`rse` | RSE boolean expression
`bytes` | The total number of bytes that can be stored

##### get-limits

To get the account limits on an RSE

    rucio-admin account get-limits [-h] account rse

###### Positional Arguments

`account` | Account name
`rse` | The RSE name

##### delete-limits

Delete quota for an account

    rucio-admin account delete-limits [-h] account rse

###### Positional Arguments

`account` | Account name
`rse` | RSE name

##### ban

Ban an account

    rucio-admin account ban [-h] --account ACCOUNT

###### Named Arguments

`--account` | Account name

##### unban

Unban a banned account

    rucio-admin account unban [-h] --account ACCOUNT

###### Named Arguments

`--account` | Account name

### identity

Identity methods

    rucio-admin identity [-h] {add,delete} ...

#### Sub-commands:

##### add

Grant an identity access to an account

    rucio-admin identity add [-h] --account ACCOUNT --type {X509,GSS,USERPASS,SSH}
                             --id IDENTITY --email EMAIL

###### Named Arguments

`--account` | Account name
`--type` | Possible choices: X509, GSS, USERPASS, SSH Authentication type [X509|GSS|USERPASS|SSH]
`--id` | Identity
`--email` | Email address associated with the identity

##### delete

Revoke an identity’s access to an account

    rucio-admin identity delete [-h] --account ACCOUNT --type
                                {X509,GSS,USERPASS,SSH} --id IDENTITY

###### Named Arguments

`--account` | Account name
`--type` | Possible choices: X509, GSS, USERPASS, SSH Authentication type [X509|GSS|USERPASS|SSH]
`--id` | Identity

### rse

RSE (Rucio Storage Element) methods

    rucio-admin rse [-h]

                    {list,add,info,set-attribute,delete-attribute,add-distance,update-distance,get-distance,get-attribute,add-protocol,delete-protocol,delete}
                    ...

#### Sub-commands:

##### list

List Rucio RSEs

    rucio-admin rse list [-h]

##### add

Add RSE

    rucio-admin rse add [-h] rse

###### Positional Arguments

`rse` | RSE name

##### info

Information about RSE

    rucio-admin rse info [-h] rse

###### Positional Arguments

`rse` | RSE name

##### set-attribute

Add RSE attribute(key-value pair)

    rucio-admin rse set-attribute [-h] --rse RSE --key KEY --value VALUE

###### Named Arguments

`--rse` | RSE name
`--key` | Attribute key
`--value` | Attribute value

##### delete-attribute

Delete a RSE attribute(key-value pair)

    rucio-admin rse delete-attribute [-h] --rse RSE --key KEY --value VALUE

###### Named Arguments

`--rse` | RSE name
`--key` | Attribute key
`--value` | Attribute value

##### add-distance

Set the distance between a pair of RSEs

    rucio-admin rse add-distance [-h] [--distance DISTANCE] [--ranking RANKING]
                                 source destination

###### Positional Arguments

`source` | Source RSE name
`destination` | Destination RSE name

###### Named Arguments

`--distance` | Distance between RSEs Default: 1
`--ranking` | Ranking of link Default: 1

##### update-distance

Update the existing distance between a pair of RSEs

    rucio-admin rse update-distance [-h] [--distance DISTANCE] [--ranking RANKING]
                                    source destination

###### Positional Arguments

`source` | Source RSE name
`destination` | Destination RSE name

###### Named Arguments

`--distance` | Distance between RSEs
`--ranking` | Ranking of link

##### get-distance

Get the distance information between a pair of RSEs

    rucio-admin rse get-distance [-h] source destination

###### Positional Arguments

`source` | Source RSE name
`destination` | Destination RSE name

##### get-attribute

List RSE attributes

    rucio-admin rse get-attribute [-h] rse

###### Positional Arguments

`rse` | RSE name

##### add-protocol

Add a protocol to a RSE

    rucio-admin rse add-protocol [-h] --hostname HOSTNAME --scheme SCHEME --prefix
                                 PREFIX [--space-token SPACE_TOKEN]
                                 [--web-service-path WEB_SERVICE_PATH]
                                 [--port PORT] [--impl IMPL]
                                 [--domain-json DOMAIN_JSON]
                                 [--extended-attributes-json EXT_ATTR_JSON]
                                 rse

###### Positional Arguments

`rse` | RSE name

###### Named Arguments

`--hostname` | Endpoint hostname
`--scheme` | Endpoint URL scheme
`--prefix` | Endpoint URL path prefix
`--space-token` | Space token name (SRM-only)
`--web-service-path`
| Web service URL (SRM-only)
`--port` | URL port
`--impl` | Transfer protocol implementation to use Default: “rucio.rse.protocols.gfalv2.Default”
`--domain-json` | JSON describing the WAN / LAN setup
`--extended-attributes-json`
| JSON describing any extended attributes

##### delete-protocol

Delete a protocol from a RSE

    rucio-admin rse delete-protocol [-h] [--hostname HOSTNAME] --scheme SCHEME
                                    [--port PORT]
                                    rse

###### Positional Arguments

`rse` | RSE name

###### Named Arguments

`--hostname` | Endpoint hostname
`--scheme` | Endpoint URL scheme
`--port` | URL port

##### delete

Disable RSE

    rucio-admin rse delete [-h] rse

###### Positional Arguments

`rse` | RSE name

### scope

Scope methods

    rucio-admin scope [-h] {add,list} ...

#### Sub-commands:

##### add

Add scope

    rucio-admin scope add [-h] --account ACCOUNT --scope SCOPE

###### Named Arguments

`--account` | Account name
`--scope` | Scope name

##### list

List scopes

    rucio-admin scope list [-h] [--account ACCOUNT]

###### Named Arguments

`--account` | Account name

### config

Configuration methods

    rucio-admin config [-h] {get,set,delete} ...

#### Sub-commands:

##### get

Get matching configuration

    rucio-admin config get [-h] [--section SECTION] [--option OPTION]

###### Named Arguments

`--section` | Section name
`--option` | Option name

##### set

Set matching configuration

    rucio-admin config set [-h] --section SECTION --option OPTION --value VALUE

###### Named Arguments

`--section` | Section name
`--option` | Option name
`--value` | String-encoded value

##### delete

Delete matching configuration

    rucio-admin config delete [-h] --section SECTION --option OPTION

###### Named Arguments

`--section` | Section name
`--option` | Option name

### subscription

Subscription methods

    rucio-admin subscription [-h] {add,list,update,reevaluate} ...

#### Sub-commands:

##### add

Add subscription

    rucio-admin subscription add [-h] [--lifetime LIFETIME]
                                 [--account SUBS_ACCOUNT] [--priority PRIORITY]
                                 name filter replication_rules comments

###### Positional Arguments

`name` | Subscription name
`filter` | DID filter (eg ‘{“scope”: [“tests”], “project”: [“data12_8TeV”]}’)
`replication_rules`
| Replication rules (eg ‘[{“copies”: 2, “rse_expression”: “tier=2”, “lifetime”: 3600, “weight”: “mou”}]’)
`comments` | Comments on subscription

###### Named Arguments

`--lifetime` | Subscription lifetime (in days)
`--account` | Account name
`--priority` | The priority of the subscription

##### list

List subscriptions

    rucio-admin subscription list [-h] [--account SUBS_ACCOUNT] [--long] [name]

###### Positional Arguments

`name` | Subscription name

###### Named Arguments

`--account` | Account name
`--long` | Long listing Default: False

##### update

Update subscription

    rucio-admin subscription update [-h] [--lifetime LIFETIME]
                                    [--account SUBS_ACCOUNT] [--priority PRIORITY]
                                    name filter replication_rules comments

###### Positional Arguments

`name` | Subscription name
`filter` | DID filter (eg ‘{“scope”: [“tests”], “project”: [“data12_8TeV”]}’)
`replication_rules`
| Replication rules (eg ‘[{“copies”: 2, “rse_expression”: “tier=2”, “lifetime”: 3600, “weight”: “mou”}]’)
`comments` | Comments on subscription

###### Named Arguments

`--lifetime` | Subscription lifetime (in days)
`--account` | Account name
`--priority` | The priority of the subscription

##### reevaluate

Reevaluate a list of DIDs against all active subscriptions

    rucio-admin subscription reevaluate [-h] dids

###### Positional Arguments

`dids` | List of DIDs (coma separated)

### replicas

Replica methods

    rucio-admin replicas [-h] {declare-bad,list-pfns} ...

#### Sub-commands:

##### declare-bad

Declare bad file replicas

    rucio-admin replicas declare-bad [-h] --reason REASON
                                     [--inputfile [INPUTFILE]]
                                     [listbadfiles [listbadfiles ...]]

###### Positional Arguments

`listbadfiles` | The list of bad files

###### Named Arguments

`--reason` | Reason
`--inputfile` | Reason

##### list-pfns

List the possible PFN for a file at a site.

    rucio-admin replicas list-pfns [-h] dids rse protocol

###### Positional Arguments

`dids` | List of DIDs (coma separated)
`rse` | RSE
`protocol` | The protocol, by default srm, can be one of [root|srm|http(s)]. Default: “srm”